#' Estimate odds ratio and confidence interval function for \code{glm(...)} model object
#'
#' This function estimates odds ratio and confidence interval.
#' To normally calculate, you must assign
#' \code{glm(..., family = "binomial", link = "logit", ...)}.
#' Default alpha level is 0.05, and this function gives Wald confidence intervals based
#' on a normal approximation.
#'
#' @param ModelName \code{glm(...)} model object name, only \code{family = "binomial" & link = "logit"}
#' @param alpha alpha level of confidence interval
#' @return
#' \item{Variables}{vector of Effect variables name}
#' \item{OddsRatioEst}{vector of estimate odds ratios}
#' \item{LowerCL}{vector of lower confidence limits}
#' \item{UpperCL}{vector of upper confidence limits}
#' \item{alpha}{alpha level of confidence interval}
#' @keywords glm
#' @export
EstOR.estimate <- function(ModelName, alpha = 0.05) {

  x <- summary(ModelName)

  if (((x$family)$family != "binomial") | ((x$family)$link != "logit")) stop()

  est       <- as.numeric(x$coefficients)
  Variables <- row.names(x$coefficients)

  if (length(est) %% 4 != 0) return()

  OddsRatioEst <- NULL; LowerCL <- NULL; UpperCL <- NULL;
  for (i in 0:(length(est)/4-1)) {
    OddsRatioEst <- append(OddsRatioEst, exp(est[1+i]))
    LowerCL <- append(LowerCL, exp(est[1+i]+qnorm(  alpha/2)*est[length(est)/4*1+1+i]))
    UpperCL <- append(UpperCL, exp(est[1+i]+qnorm(1-alpha/2)*est[length(est)/4*1+1+i]))
  }

  EstOR_res <- list(
    Variables    = Variables,
    OddsRatioEst = OddsRatioEst,
    LowerCL      = LowerCL,
    UpperCL      = UpperCL,
    alpha        = alpha
  )

  class(EstOR_res) <- "EstOR.estimate"
  return(EstOR_res)

}
